from notionai import NotionAI, NotionAIStream
import sys
import os

TOKEN = os.getenv("NOTION_TOKEN")
SPACE_ID = os.getenv("NOTION_SPACE_ID")


def write_blog(prompt: str):
    ai = NotionAI(TOKEN, SPACE_ID)
    res = ai.blog_post(prompt)
    print(res)


def write_blog_stream(prompt: str):
    ai = NotionAIStream(TOKEN, SPACE_ID)
    res = ai.blog_post(prompt)
    for item in res:
        sys.stdout.write(item)


def main():
    prompt = "Introduce Notion"
    write_blog(prompt)
    write_blog_stream(prompt)


if __name__ == "__main__":
    main()



import os

import gradio as gr
from notionai import (
    NotionAI,
    PromptTypeEnum,
    TopicEnum,
    TranslateLanguageEnum,
    ToneEnum,
)

TOKEN = os.getenv("NOTION_TOKEN")
SPACE_ID = os.getenv("NOTION_SPACE_ID")
ai = NotionAI(TOKEN, SPACE_ID)

TOPIC_MAPPING = {item.name: item for item in TopicEnum}
LANGUAGE_MAPPING = {item.name: item for item in TranslateLanguageEnum}
PROMPT_TYPE_MAPPING = {item.name: item for item in PromptTypeEnum}
TONE_MAPPING = {item.name: item for item in ToneEnum}


def write_by_topic(topic, prompt):
    res = ai.writing_with_topic(TOPIC_MAPPING[topic], prompt)
    return res


def translate(language, text):
    return ai.translate(LANGUAGE_MAPPING[language], text)


def summarize(prompt_type, context):
    return ai.writing_with_prompt(PROMPT_TYPE_MAPPING[prompt_type], context)


def change_tone(tone, text):
    return ai.change_tone(text, TONE_MAPPING[tone])


def help_me_write(prompt, context):
    return ai.help_me_write(prompt, context)


app = gr.Blocks()

with app:
    gr.Markdown("Notion AI is here to serve your every need and make your life easier.")
    with gr.Tabs():
        with gr.TabItem("Help me Write"):
            with gr.Column():
                help_me_write_context = gr.Textbox(
                    lines=3,
                    placeholder="Let me help you write on the context.",
                    label="Context",
                )
                help_me_write_prompt = gr.Textbox(
                    lines=3,
                    placeholder="Please inpout your prompt here",
                    label="Prompt",
                )
                help_me_write_output = gr.Markdown(
                    label="AI response", visible=True, value="Notion AI Says..."
                )
            help_me_write_button = gr.Button("Help me Write", label="Help me Write")
        with gr.TabItem("Write with Tpoics"):
            with gr.Column():
                topic_type = gr.Dropdown(
                    choices=list(TOPIC_MAPPING.keys()),
                    value=TopicEnum.blog_post.name,
                    label="Topic",
                )
                topic_prompt = gr.Textbox(
                    lines=3,
                    placeholder="Let me help you write on the topic.",
                    label="Prompt",
                )
                topic_output = gr.Markdown(
                    label="AI response", visible=True, value="Notion AI Says..."
                )
            topic_button = gr.Button("Write", label="Write")
        with gr.TabItem("Translate"):
            with gr.Column():
                translate_language = gr.Dropdown(
                    choices=list(LANGUAGE_MAPPING.keys()),
                    label="Target Language",
                    value=TranslateLanguageEnum.japanese.name,
                )
                translate_text = gr.Textbox(
                    lines=2, placeholder="Translate texts", label="Text"
                )
                translate_output = gr.Markdown(
                    label="Translate response", visible=True, value="Translating..."
                )
            translate_button = gr.Button("Translate", label="Translate")
        with gr.TabItem("ChangeTone"):
            with gr.Column():
                tone = gr.Dropdown(
                    choices=list(TONE_MAPPING.keys()),
                    label="Which tone do you want to change to?",
                    value=ToneEnum.professional.name,
                )
                tone_text = gr.Textbox(lines=2, placeholder="Your texts", label="Text")
                tone_output = gr.Markdown(
                    label="Tone Response", visible=True, value="processing..."
                )
            change_tone_button = gr.Button("ChangeTone", label="change_tone")
        with gr.TabItem("More..."):
            with gr.Column():
                summary_type = gr.Dropdown(
                    choices=[
                        item
                        for item in PROMPT_TYPE_MAPPING.keys()
                        if item != PromptTypeEnum.translate.name
                        and item != PromptTypeEnum.change_tone.name
                        and item != PromptTypeEnum.help_me_edit.name
                        and item != PromptTypeEnum.help_me_write.name
                    ],
                    label="Prompt Type",
                    value=PromptTypeEnum.improve_writing.name,
                )
                summarize_text = gr.Textbox(
                    lines=2, placeholder="How to process your text?", label="Texts"
                )
                summarize_output = gr.Markdown(
                    label="Summarize response", visible=True, value="Processing..."
                )
            summarize_button = gr.Button("Summarize", label="Summarize")

    help_me_write_button.click(
        help_me_write,
        inputs=[help_me_write_prompt, help_me_write_context],
        outputs=help_me_write_output,
    )
    topic_button.click(
        write_by_topic, inputs=[topic_type, topic_prompt], outputs=topic_output
    )
    translate_button.click(
        translate, inputs=[translate_language, translate_text], outputs=translate_output
    )
    change_tone_button.click(change_tone, inputs=[tone, tone_text], outputs=tone_output)
    summarize_button.click(
        summarize,
        inputs=[summary_type, summarize_text],
        outputs=summarize_output,
    )

app.launch(debug=True)



import os
import time

import pytest

from notionai import NotionAI
from notionai.enums import PromptTypeEnum, ToneEnum, TopicEnum, TranslateLanguageEnum

ai = NotionAI(token=os.getenv("NOTION_TOKEN"))


@pytest.fixture(autouse=True)
def wait_for_ratelimit():
    yield
    time.sleep(10)


def test_translate():
    prompt = "test translate prompt, 测试翻译"
    for lang in TranslateLanguageEnum.list():
        res = ai.translate(context=prompt, language=TranslateLanguageEnum(lang))
        assert res != "", f"lang:{lang}\t prompt:{prompt}\t res:{res}"


def test_writing_with_topic():
    prompt = "test writing with topic prompt"
    for topic in TopicEnum.list():
        res = ai.writing_with_topic(topic=TopicEnum(topic), prompt=prompt)
        assert res != "", f"topic: {topic}\t prompt:{prompt}\t res: {res}"


def test_writing_with_prompt():
    prompt = "using pytest to test writing with prompt"
    for prompt_type in PromptTypeEnum.list():
        if prompt_type in {
            PromptTypeEnum.translate.value,
            PromptTypeEnum.help_me_edit.value,
            PromptTypeEnum.change_tone.value,
            PromptTypeEnum.help_me_write.value,
        }:
            continue
        res = ai.writing_with_prompt(
            prompt_type=PromptTypeEnum(prompt_type), context=prompt
        )
        assert res != "", f"prompt_type: {prompt_type}\t prompt:{prompt}\t res: {res}"


def test_change_tone():
    prompt = "I dont like this tone"
    for tone in ToneEnum.list():
        res = ai.change_tone(context=prompt, tone=ToneEnum(tone))
        assert res != "", f"tone: {tone}\t prompt:{prompt}\t res: {res}"


def test_help_me_edit():
    prompt = "write something for me about NotionAI"
    context = "I am using NotionAI to write something"
    res = ai.help_me_edit(prompt=prompt, context=context, page_title="NotionAI")
    assert res != "", f"prompt: {prompt}\t res: {res}"


def test_help_me_write():
    prompt = "write something for me about NotionAI"
    context = "I am using NotionAI to write something"
    res = ai.help_me_write(prompt=prompt, context=context, page_title="NotionAI")
    assert res != "", f"prompt: {prompt}\t res: {res}"



import json
import uuid

import requests

from notionai.enums import PromptTypeEnum, ToneEnum, TopicEnum, TranslateLanguageEnum

MODEL = "openai-3"
URL = "https://www.notion.so/api/v3/getCompletion"


class NotionAIBase(object):
    stream = False

    def __init__(
        self,
        token: str,
        space_id: str,
        model: str = MODEL,
    ) -> None:
        """Init NotionAI
        Args:
            token (str): Notion token_v2
            space_id (str): Notion workspace id
            model (str, optional): AI model. Default to openai-1.1
            stream (bool, optional): use stream result. Defaults to False.
            pageTitle (str, optional): Title for your content. Defaults to PAGE_TITLE.
        """
        self.token = token
        self.space_id = space_id
        self.model = model
        self.is_space_permission = False
        self.url = URL

    def _request(self, content: dict) -> str:
        payload = {
            "id": self._get_id(),
            "model": self.model,
            "spaceId": self.space_id,
            "isSpacePermission": self.is_space_permission,
            "context": content,
        }

        headers = self._build_headers(self.token)
        return requests.post(
            self.url, json=payload, headers=headers, stream=self.stream
        )

    def _build_headers(self, token: str):
        cookies = [
            "token_v2=" + token,
        ]

        return {
            "accept": "application/json",
            "Cookie": "; ".join(cookies),
            "Content-Type": "application/json",
        }

    def _post(self, content: dict) -> str:
        r = self._request(content)
        data = r.text.split("\n")
        res = [self._parse_resp_line(d) for d in data]
        return "".join(res).strip("\n")

    def _parse_resp_line(self, line):
        if line:
            try:
                data = json.loads(line)
                if data["type"] == "success":
                    return data["completion"]
            except Exception as e:
                print(f"data: {line}, error: {e}")
        return ""

    def _get_id(self) -> str:
        return str(uuid.uuid4())


class NotionAI(NotionAIBase):
    @classmethod
    def get_spaces(cls, token: str) -> list[dict]:
        """Get all spaces
        Params:
            token (str): Notion token_v2

        Returns:
            list[dict]: list of spaces with id and name

        Example: [
            {"id": "space_id_1", "name": "space_name"},
            {"id": "space_id_2", "name": "space_name"}
        ]
        """
        url = "https://www.notion.so/api/v3/getSpaces"
        r = requests.post(url, headers=cls._build_headers(token))
        if r.status_code != 200:
            raise ValueError("Cannot get spaces")
        res = r.json()
        spaces = []
        for _, val in res.items():
            space = val.get("space")
            if space:
                for k, v in space.items():
                    space_id = k
                    space_name = v["value"]["name"]
                    spaces.append({"id": space_id, "name": space_name})
        return spaces

    def writing_with_topic(self, topic: TopicEnum, prompt: str) -> str:
        """Writing for special topic

        Args:
            topic (TopicEnum): the special topic
            prompt (str): prompt for writing

        Returns:
            str: Response from NotionAI
        """
        content = {"type": topic.value, "topic": prompt}
        return self._post(content)

    def writing_with_prompt(
        self,
        prompt_type: PromptTypeEnum,
        context: str,
        page_title: str = "",
    ) -> str:
        """Writing with special prompt, like summarize, explain_this, improve_writing

        Args:
            prompt_type (PromptTypeEnum): special prompt
            context (str): the context for your writing
            page_title (str, optional): I am not sure about this. Defaults to ""

        Returns:
            str: Response from NotionAI
        """
        if prompt_type == PromptTypeEnum.continue_writing:
            return self.continue_write(context, page_title)

        if prompt_type in {
            PromptTypeEnum.help_me_write,
            PromptTypeEnum.help_me_edit,
            PromptTypeEnum.translate,
            PromptTypeEnum.change_tone,
        }:
            raise ValueError("Please use the specific method for this prompt type")
        content = {
            "type": prompt_type.value,
            "pageTitle": page_title,
            "selectedText": context,
        }
        return self._post(content)

    def help_me_write(
        self, prompt: str, context: str, page_title: str = "", rest_content: str = ""
    ) -> str:
        """Help me write, ask AI to write for you

        Args:
            prompt (str): your prompt, could be anything
            context (str): context for your writing
            page_title (str, optional): not sure. Defaults to "".
            rest_content (str, optional): more context. Defaults to "".

        Returns:
            str: Response from NotionAI
        """
        content = {
            "type": PromptTypeEnum.help_me_write.value,
            "prompt": prompt,
            "pageTitle": page_title,
            "previousContent": context,
            "restContent": rest_content,
        }
        return self._post(content)

    def continue_write(
        self, context: str, page_title: str = "", rest_content: str = ""
    ) -> str:
        """Continue writing, generating more

        Args:
            context (str): context for continue
            page_title (str, optional): not sure. Defaults to "".
            rest_content (str, optional): more context. Defaults to "".

        Returns:
            str: Response from NotionAI
        """
        content = {
            "type": PromptTypeEnum.continue_writing.value,
            "pageTitle": page_title,
            "previousContent": context,
            "restContent": rest_content,
        }
        return self._post(content)

    def help_me_edit(self, prompt: str, context: str, page_title: str = "") -> str:
        """Help me edit somethings, it will change the current context

        Args:
            prompt (str): your prompt, could be anything
            context (str): context to edit
            page_title (str, optional): not sure. Defaults to "".

        Returns:
            str: Response from NotionAI
        """

        content = {
            "type": PromptTypeEnum.help_me_edit.value,
            "pageTitle": page_title,
            "prompt": prompt,
            "selectedText": context,
        }
        return self._post(content)

    def translate(self, language: TranslateLanguageEnum, context: str) -> str:
        """Use NotionAI to translate your context

        Args:
            language (TranslateLanguageEnum): target language
            context (str): context to translate

        Returns:
            str: translate result
        """
        content = {
            "type": PromptTypeEnum.translate.value,
            "text": context,
            "language": language.value,
        }
        return self._post(content)

    def change_tone(self, context: str, tone: ToneEnum) -> str:
        """Change the tone of your context

        Args:
            context (str): context to change
            tone (ToneEnum): target tone

        Returns:
            str: Response from NotionAI
        """
        content = {
            "type": "changeTone",
            "tone": tone.value,
            "text": context,
        }
        return self._post(content)

    def summarize(self, context: str, page_title: str = "") -> str:
        return self.writing_with_prompt(PromptTypeEnum.summarize, context)

    def improve_writing(self, context: str, page_title: str = "") -> str:
        return self.writing_with_prompt(PromptTypeEnum.improve_writing, context)

    def fix_spelling_grammar(self, context: str, page_title: str = "") -> str:
        return self.writing_with_prompt(
            PromptTypeEnum.fix_spelling_grammar,
            context,
            page_title=page_title,
        )

    def explain_this(self, context: str, page_title: str = "") -> str:
        return self.writing_with_prompt(
            PromptTypeEnum.explain_this, context, page_title=page_title
        )

    def make_longer(self, context: str, page_title: str = "") -> str:
        return self.writing_with_prompt(
            PromptTypeEnum.make_longer, context, page_title=page_title
        )

    def make_shorter(self, context: str, page_title: str = "") -> str:
        return self.writing_with_prompt(
            PromptTypeEnum.make_shorter, context, page_title=page_title
        )

    def find_action_items(self, context: str, page_title: str = "") -> str:
        return self.writing_with_prompt(
            PromptTypeEnum.find_action_items, context, page_title=page_title
        )

    def simplify_language(self, context: str, page_title: str = "") -> str:
        return self.writing_with_prompt(
            PromptTypeEnum.simplify_language, context, page_title=page_title
        )

    def blog_post(self, prompt: str) -> str:
        return self.writing_with_topic(TopicEnum.blog_post, prompt)

    def brainstorm_ideas(self, prompt: str) -> str:
        return self.writing_with_topic(TopicEnum.brainstorm_ideas, prompt)

    def outline(self, prompt: str) -> str:
        return self.writing_with_topic(TopicEnum.outline, prompt)

    def social_media_post(self, prompt: str) -> str:
        return self.writing_with_topic(TopicEnum.social_media_post, prompt)

    def creative_story(self, prompt: str) -> str:
        return self.writing_with_topic(TopicEnum.creative_story, prompt)

    def poem(self, prompt: str) -> str:
        return self.writing_with_topic(TopicEnum.poem, prompt)

    def essay(self, prompt: str) -> str:
        return self.writing_with_topic(TopicEnum.essay, prompt)

    def meeting_agenda(self, prompt: str) -> str:
        return self.writing_with_topic(TopicEnum.meeting_agenda, prompt)

    def press_release(self, prompt: str) -> str:
        return self.writing_with_topic(TopicEnum.press_release, prompt)

    def job_description(self, prompt: str) -> str:
        return self.writing_with_topic(TopicEnum.job_description, prompt)

    def sales_email(self, prompt: str) -> str:
        return self.writing_with_topic(TopicEnum.sales_email, prompt)

    def recruiting_email(self, prompt: str) -> str:
        return self.writing_with_topic(TopicEnum.recruiting_email, prompt)

    def pros_cons_list(self, prompt: str) -> str:
        self.writing_with_topic(TopicEnum.pros_cons_list, prompt)


class NotionAIStream(NotionAI):
    stream = True

    def _post(self, content: dict) -> str:
        r = self._request(content)
        for line in r.text.splitlines():
            yield self._parse_resp_line(line)



from enum import Enum


class ExtendedEnum(Enum):
    @classmethod
    def list(cls):
        return list(map(lambda c: c.value, cls))

    @classmethod
    def list_name(cls):
        return list(map(lambda c: c.name, cls))


class TopicEnum(ExtendedEnum):
    brainstorm_ideas = "brainstormIdeas"
    blog_post = "blogPost"
    outline = "outline"
    social_media_post = "socialMediaPost"
    press_release = "pressRelease"
    creative_story = "creativeStory"
    essay = "essay"
    poem = "poem"
    meeting_agenda = "meetingAgenda"
    pros_cons_list = "prosConsList"
    job_description = "jobDescription"
    sales_email = "salesEmail"
    recruiting_email = "recruitingEmail"


class TranslateLanguageEnum(ExtendedEnum):
    english = "english"
    korean = "korean"
    chinese = "chinese"
    japanese = "japanese"
    spanish = "spanish"
    russiab = "russiab"
    french = "french"
    german = "german"
    italian = "italian"
    portuguese = "portuguese"
    dutch = "dutch"
    indonesia = "indonesia"
    tagalog = "tagalog"
    vietnamese = "vietnamese"


class PromptTypeEnum(ExtendedEnum):
    help_me_write = "helpMeWrite"
    continue_writing = "continueWriting"
    change_tone = "changeTone"
    summarize = "summarize"
    improve_writing = "improveWriting"
    fix_spelling_grammar = "fixSpellingGrammar"
    translate = "translate"
    explain_this = "explainThis"
    make_longer = "makeLonger"
    make_shorter = "makeShorter"
    find_action_items = "findActionItems"
    simplify_language = "simplifyLanguage"
    help_me_edit = "helpMeEdit"


class ToneEnum(ExtendedEnum):
    professional = "professional"
    casual = "casual"
    straight_forward = "straightforward"
    confident = "confident"
    friendly = "friendly"
